@@ -1212,6 +1212,9 @@ def http_endpoint(path, require_credentials=False, authenticate_users=False, aut
                     d["Access-Control-Allow-Origin"] = enable_cors if isinstance(enable_cors, str) else "*"
                 elif same_app_alternate_origin:
                     d["Access-Control-Allow-Origin"] = same_app_alternate_origin
+                if enable_cors or same_app_alternate_origin and \
+                        "access-control-allow-headers" not in [h.lower() for h in d.keys()]:
+                    d["Access-Control-Allow-Headers"] = "content-type"
                 return d
 
             if method not in methods:
